@@ -1,7 +1,7 @@
 # PMML: Predictive Model Markup Language
 #
 # Copyright (c) 2009-2016, Zementis, Inc.
-# Copyright (c) 2016-2020, Software AG, Darmstadt, Germany and/or Software AG
+# Copyright (c) 2016-2021, Software AG, Darmstadt, Germany and/or Software AG
 # USA Inc., Reston, VA, USA, and/or its subsidiaries and/or its affiliates
 # and/or their licensors.
 #
@@ -67,6 +67,7 @@ pmml.naiveBayes <- function(model,
                             app_name = "SoftwareAG PMML Generator",
                             description = "NaiveBayes Model",
                             copyright = NULL,
+                            model_version = NULL,
                             transforms = NULL,
                             missing_value_replacement = NULL,
                             predicted_field,
@@ -138,7 +139,8 @@ pmml.naiveBayes <- function(model,
 
   # PMML -> Header
 
-  pmml <- append.XMLNode(pmml, .pmmlHeader(description, copyright, app_name))
+  pmml <- append.XMLNode(pmml, .pmmlHeader(description, copyright, model_version,
+                                           app_name))
 
   # PMML -> DataDictionary
 
